@@ -147,13 +147,11 @@ void MainShellTest::initTestCase()
     // Register in bus as okular
 #if HAVE_DBUS
     QDBusConnectionInterface *bus = QDBusConnection::sessionBus().interface();
-    const QString myPid = QString::number(getpid());
-    const QString serviceName = QStringLiteral("org.kde.okular-") + myPid;
-    QVERIFY(bus->registerService(serviceName) == QDBusConnectionInterface::ServiceRegistered);
+    QVERIFY(bus->registerService(ShellUtils::currentProcessDbusName()) == QDBusConnectionInterface::ServiceRegistered);
 #endif
     // Tell the presentationWidget and queryClose to not be annoying
     KSharedConfigPtr c = KSharedConfig::openConfig(QStringLiteral("mainshelltest.kmessagebox"));
-    KConfigGroup cg = c->group("General");
+    KConfigGroup cg = c->group(QStringLiteral("General"));
     cg.writeEntry("presentationInfo", 4);
     cg.writeEntry("ShowTabWarning", 4);
 }
