@@ -15,12 +15,13 @@
 #include "global.h"
 #include "okularcore_export.h"
 #include "pagesize.h"
+#include "signatureutils.h"
 
 #include <QDomDocument>
+#include <QList>
 #include <QObject>
 #include <QPrinter>
 #include <QStringList>
-#include <QVector>
 
 #include <QMimeType>
 #include <QUrl>
@@ -308,12 +309,12 @@ public:
      * Sets the list of visible page rectangles.
      * @see VisiblePageRect
      */
-    void setVisiblePageRects(const QVector<VisiblePageRect *> &visiblePageRects, DocumentObserver *excludeObserver = nullptr);
+    void setVisiblePageRects(const QList<VisiblePageRect *> &visiblePageRects, DocumentObserver *excludeObserver = nullptr);
 
     /**
      * Returns the list of visible page rectangles.
      */
-    const QVector<VisiblePageRect *> &visiblePageRects() const;
+    const QList<VisiblePageRect *> &visiblePageRects() const;
 
     /**
      * Returns the number of the current page.
@@ -1102,9 +1103,10 @@ public:
     /**
      * Digitally sign document
      *
-     * @since 21.04
+     * @return pair of signing result and a detailed/advanced error message/code in case of errors
+     * @since 25.08
      */
-    bool sign(const NewSignatureData &data, const QString &newPath);
+    std::pair<SigningResult, QString> sign(const NewSignatureData &data, const QString &newPath);
 
     /**
      * Returns the generator's certificate store (if any)
@@ -1433,6 +1435,7 @@ private:
     friend class EditFormListCommand;
     friend class EditFormComboCommand;
     friend class EditFormButtonsCommand;
+    friend class KleopatraIntegration;
     /// @endcond
     DocumentPrivate *const d;
 
