@@ -18,7 +18,7 @@ DocumentObserver::~DocumentObserver()
 {
 }
 
-void DocumentObserver::notifySetup(const QVector<Okular::Page *> &, int)
+void DocumentObserver::notifySetup(const QList<Okular::Page *> &, int)
 {
 }
 
