@@ -287,7 +287,7 @@ QJSValue JSApp::setInterval(const QString &cExpr, int nMilliseconds)
 {
     QTimer *timer = new QTimer();
 
-    QObject::connect(timer, &QTimer::timeout, m_doc->m_parent, [=]() { m_doc->executeScript(cExpr); });
+    QObject::connect(timer, &QTimer::timeout, m_doc->m_parent, [=, this]() { m_doc->executeScript(cExpr); });
 
     timer->start(nMilliseconds);
 
@@ -312,7 +312,7 @@ QJSValue JSApp::setTimeOut(const QString &cExpr, int nMilliseconds)
     QTimer *timer = new QTimer();
     timer->setSingleShot(true);
 
-    QObject::connect(timer, &QTimer::timeout, m_doc->m_parent, [=]() { m_doc->executeScript(cExpr); });
+    QObject::connect(timer, &QTimer::timeout, m_doc->m_parent, [=, this]() { m_doc->executeScript(cExpr); });
 
     timer->start(nMilliseconds);
 
