@@ -81,7 +81,7 @@ Q_SIGNALS:
      *
      * @since 0.7 (KDE 4.1)
      */
-    void addMetaData(DocumentInfo::Key key, const QString &value);
+    void addMetaData(Okular::DocumentInfo::Key key, const QString &value);
 
     /**
      * This signal should be emitted whenever an error occurred in the converter.
@@ -169,7 +169,7 @@ public:
     ~TextDocumentGenerator() override;
 
     // [INHERITED] load a document and fill up the pagesVector
-    Document::OpenResult loadDocumentWithPassword(const QString &fileName, QVector<Okular::Page *> &pagesVector, const QString &password) override;
+    Document::OpenResult loadDocumentWithPassword(const QString &fileName, QList<Okular::Page *> &pagesVector, const QString &password) override;
 
     // [INHERITED] perform actions on document / pages
     bool canGeneratePixmap() const override;
