@@ -296,9 +296,9 @@ KDjVu::TextAnnotation::TextAnnotation(miniexp_t anno)
 QSize KDjVu::TextAnnotation::size() const
 {
     miniexp_t area = miniexp_nth(3, m_anno);
-    int c = miniexp_to_int(miniexp_nth(3, area));
-    int d = miniexp_to_int(miniexp_nth(4, area));
-    return QSize(c, d);
+    int w = miniexp_to_int(miniexp_nth(3, area));
+    int h = miniexp_to_int(miniexp_nth(4, area));
+    return QSize(w, h);
 }
 
 int KDjVu::TextAnnotation::type() const
@@ -374,9 +374,9 @@ void KDjVu::LineAnnotation::setColor(const QColor &color)
 QPoint KDjVu::LineAnnotation::point2() const
 {
     miniexp_t area = miniexp_nth(3, m_anno);
-    int c = miniexp_to_int(miniexp_nth(3, area));
-    int d = miniexp_to_int(miniexp_nth(4, area));
-    return QPoint(c, d);
+    int x = miniexp_to_int(miniexp_nth(3, area));
+    int y = miniexp_to_int(miniexp_nth(4, area));
+    return QPoint(x, y);
 }
 
 bool KDjVu::LineAnnotation::isArrow() const
@@ -443,8 +443,8 @@ public:
     ddjvu_document_t *m_djvu_document;
     ddjvu_format_t *m_format;
 
-    QVector<KDjVu::Page> m_pages;
-    QVector<ddjvu_page_t *> m_pages_cache;
+    QList<KDjVu::Page> m_pages;
+    QList<ddjvu_page_t *> m_pages_cache;
 
     QList<ImageCacheItem *> mImgCache;
 
@@ -485,7 +485,7 @@ QImage KDjVu::Private::generateImageTile(ddjvu_page_t *djvupage, int &res, int w
     // the following line workarounds a rare crash in djvulibre;
     // it should be fixed with >= 3.5.21
     ddjvu_page_get_width(djvupage);
-    res = ddjvu_page_render(djvupage, DDJVU_RENDER_COLOR, &pagerect, &renderrect, m_format, res_img.bytesPerLine(), (char *)res_img.bits());
+    res = ddjvu_page_render(djvupage, DDJVU_RENDER_COLOR, &pagerect, &renderrect, m_format, res_img.bytesPerLine(), reinterpret_cast<char *>(res_img.bits()));
     if (!res) {
         res_img.fill(Qt::white);
     }
@@ -729,7 +729,7 @@ void KDjVu::closeFile()
     // deleting the pages
     d->m_pages.clear();
     // releasing the djvu pages
-    QVector<ddjvu_page_t *>::Iterator it = d->m_pages_cache.begin(), itEnd = d->m_pages_cache.end();
+    QList<ddjvu_page_t *>::Iterator it = d->m_pages_cache.begin(), itEnd = d->m_pages_cache.end();
     for (; it != itEnd; ++it) {
         ddjvu_page_release(*it);
     }
@@ -854,7 +854,7 @@ void KDjVu::linksAndAnnotationsForPage(int pageNum, QList<KDjVu::Link *> *links,
     }
 }
 
-const QVector<KDjVu::Page> &KDjVu::pages() const
+const QList<KDjVu::Page> &KDjVu::pages() const
 {
     return d->m_pages;
 }
@@ -997,7 +997,7 @@ bool KDjVu::exportAsPostScript(QFile *file, const QList<int> &pageList) const
 
     // setting the options
     static const int optc = 1;
-    const char **optv = (const char **)malloc(1 * sizeof(char *));
+    const char *optv[1] = {};
     QByteArray plb = pl.toLatin1();
     optv[0] = plb.constData();
 
@@ -1006,8 +1006,6 @@ bool KDjVu::exportAsPostScript(QFile *file, const QList<int> &pageList) const
         handle_ddjvu_messages(d->m_djvu_cxt, true);
     }
 
-    free(static_cast<void *>(optv));
-
     return fclose(f) == 0;
 }
 
