@@ -109,11 +109,7 @@ void dviRenderer::set_char(unsigned int cmd, unsigned int ch)
             Hyperlink dhl;
             dhl.baseline = currinf.data.pxl_v;
             dhl.box.setRect(x, y, pix.width(), pix.height());
-            if (source_href != nullptr) {
-                dhl.linkText = *source_href;
-            } else {
-                dhl.linkText = QLatin1String("");
-            }
+            dhl.linkText = *source_href;
             currentDVIPage->sourceHyperLinkList.push_back(dhl);
         } else {
             QRect dshunion = currentDVIPage->sourceHyperLinkList[currentDVIPage->sourceHyperLinkList.size() - 1].box.united(QRect(x, y, pix.width(), pix.height()));
@@ -257,7 +253,7 @@ void dviRenderer::draw_part(double current_dimconv, bool is_vfmacro)
     currinf.set_char_p = &dviRenderer::set_no_char;
 
     int last_space_index = 0;
-    bool space_encountered = false;
+    bool space_encountered;
     bool after_space = false;
     for (;;) {
         space_encountered = false;
@@ -544,7 +540,7 @@ void dviRenderer::draw_part(double current_dimconv, bool is_vfmacro)
                 errorMsg = i18n("The unknown op-code %1 was encountered.", ch);
                 return;
             } /* end switch*/
-        }     /* end else (ch not a SETCHAR or FNTNUM) */
+        } /* end else (ch not a SETCHAR or FNTNUM) */
 
 #ifdef DEBUG_RENDER
         if (currentlyDrawnPage->textBoxList.size() > 0)
