@@ -57,7 +57,7 @@ void Converter::_emitData(Okular::DocumentInfo::Key key, enum epub_metadata type
     data = epub_get_metadata(mTextDocument->getEpub(), type, &size);
 
     if (data) {
-        Q_EMIT addMetaData(key, _strPack((char **)data, size));
+        Q_EMIT addMetaData(key, _strPack(reinterpret_cast<char **>(data), size));
         for (int i = 0; i < size; i++) {
             free(data[i]);
         }
@@ -128,7 +128,7 @@ void Converter::_insert_local_links(const QString &key, const QPair<int, int> va
     if (mLocalLinks.contains(key)) {
         mLocalLinks[key].append(value);
     } else {
-        QVector<QPair<int, int>> vec;
+        QList<QPair<int, int>> vec;
         vec.append(value);
         mLocalLinks.insert(key, vec);
     }
@@ -191,8 +191,8 @@ QTextDocument *Converter::convert(const QString &fileName)
 
     // if the background color of the document is non-white it will be handled by QTextDocument::setHtml()
     bool firstPage = true;
-    QVector<Okular::MovieAnnotation *> movieAnnots;
-    QVector<Okular::SoundAction *> soundActions;
+    QList<Okular::MovieAnnotation *> movieAnnots;
+    QList<Okular::SoundAction *> soundActions;
 
     const QSize videoSize(320, 240);
     do {
@@ -386,7 +386,7 @@ QTextDocument *Converter::convert(const QString &fileName)
                             block = _cursor->block();
                             QImage image;
                             mSectionMap.insert(link, block);
-                            if (image.loadFromData((unsigned char *)data, size)) {
+                            if (image.loadFromData(reinterpret_cast<unsigned char *>(data), size)) {
                                 mTextDocument->addResource(QTextDocument::ImageResource, QUrl(link), image);
                                 _cursor->insertImage(link);
                             } else {
@@ -427,7 +427,7 @@ QTextDocument *Converter::convert(const QString &fileName)
     }
 
     // adding link actions
-    QHashIterator<QString, QVector<QPair<int, int>>> hit(mLocalLinks);
+    QHashIterator<QString, QList<QPair<int, int>>> hit(mLocalLinks);
     while (hit.hasNext()) {
         hit.next();
 
