@@ -480,7 +480,7 @@ Okular::Action *createLinkFromPopplerLink(std::variant<const Poppler::Link *, st
 
     case Poppler::Link::Sound: {
         auto popplerLinkSound = static_cast<const Poppler::LinkSound *>(rawPopplerLink);
-        Poppler::SoundObject *popplerSound = popplerLinkSound->sound();
+        const Poppler::SoundObject *popplerSound = popplerLinkSound->sound();
         Okular::Sound *sound = createSoundFromPopplerSound(popplerSound);
         link = new Okular::SoundAction(popplerLinkSound->volume(), popplerLinkSound->synchronous(), popplerLinkSound->repeat(), popplerLinkSound->mix(), sound);
     } break;
@@ -573,7 +573,7 @@ Okular::Action *createLinkFromPopplerLink(std::variant<const Poppler::Link *, st
     case Poppler::Link::Hide: {
         const Poppler::LinkHide *l = static_cast<const Poppler::LinkHide *>(rawPopplerLink);
         QStringList scripts;
-        const QVector<QString> targets = l->targets();
+        const QList<QString> targets = l->targets();
         for (const QString &target : targets) {
             scripts << QStringLiteral("getField(\"%1\").hidden = %2;").arg(target).arg(l->isShowAction() ? QLatin1String("false") : QLatin1String("true"));
         }
@@ -613,8 +613,8 @@ Okular::Action *createLinkFromPopplerLink(std::variant<const Poppler::Link *, st
     }
 
     if (link) {
-        QVector<Okular::Action *> nextActions;
-        const QVector<Poppler::Link *> nextLinks = rawPopplerLink->nextLinks();
+        QList<Okular::Action *> nextActions;
+        const QList<Poppler::Link *> nextLinks = rawPopplerLink->nextLinks();
         for (const Poppler::Link *nl : nextLinks) {
             nextActions << createLinkFromPopplerLink(nl);
         }
@@ -701,6 +701,9 @@ PDFGenerator::PDFGenerator(QObject *parent, const QVariantList &args)
     auto activeBackend = PDFSettingsWidget::settingStringToPopplerEnum(PDFSettings::signatureBackend());
     if (activeBackend) {
         Poppler::setActiveCryptoSignBackend(activeBackend.value());
+        if (activeBackend == Poppler::CryptoSignBackend::GPG) {
+            setActiveCertificateBackend(Okular::CertificateInfo::Backend::Gpg);
+        }
     }
 #endif
 #if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(25, 02, 90)
@@ -718,7 +721,7 @@ PDFGenerator::~PDFGenerator()
 }
 
 // BEGIN Generator inherited functions
-Okular::Document::OpenResult PDFGenerator::loadDocumentWithPassword(const QString &filePath, QVector<Okular::Page *> &pagesVector, const QString &password)
+Okular::Document::OpenResult PDFGenerator::loadDocumentWithPassword(const QString &filePath, QList<Okular::Page *> &pagesVector, const QString &password)
 {
 #ifndef NDEBUG
     if (pdfdoc) {
@@ -732,7 +735,7 @@ Okular::Document::OpenResult PDFGenerator::loadDocumentWithPassword(const QStrin
     return init(pagesVector, password);
 }
 
-Okular::Document::OpenResult PDFGenerator::loadDocumentFromDataWithPassword(const QByteArray &fileData, QVector<Okular::Page *> &pagesVector, const QString &password)
+Okular::Document::OpenResult PDFGenerator::loadDocumentFromDataWithPassword(const QByteArray &fileData, QList<Okular::Page *> &pagesVector, const QString &password)
 {
 #ifndef NDEBUG
     if (pdfdoc) {
@@ -746,7 +749,7 @@ Okular::Document::OpenResult PDFGenerator::loadDocumentFromDataWithPassword(cons
     return init(pagesVector, password);
 }
 
-Okular::Document::OpenResult PDFGenerator::init(QVector<Okular::Page *> &pagesVector, const QString &password)
+Okular::Document::OpenResult PDFGenerator::init(QList<Okular::Page *> &pagesVector, const QString &password)
 {
     if (!pdfdoc) {
         return Okular::Document::OpenError;
@@ -832,7 +835,7 @@ Okular::Action *PDFGenerator::additionalDocumentAction(Okular::Document::Documen
     return nullptr;
 }
 
-PDFGenerator::SwapBackingFileResult PDFGenerator::swapBackingFile(QString const &newFileName, QVector<Okular::Page *> &newPagesVector)
+PDFGenerator::SwapBackingFileResult PDFGenerator::swapBackingFile(QString const &newFileName, QList<Okular::Page *> &newPagesVector)
 {
     const QBitArray oldRectsGenerated = rectsGenerated;
 
@@ -847,10 +850,9 @@ PDFGenerator::SwapBackingFileResult PDFGenerator::swapBackingFile(QString const
     if (oldRectsGenerated.count() == rectsGenerated.count()) {
         for (int i = 0; i < oldRectsGenerated.count(); ++i) {
             if (oldRectsGenerated[i]) {
-                Okular::Page *page = newPagesVector[i];
-
                 std::unique_ptr<Poppler::Page> pp = pdfdoc->page(i);
                 if (pp) {
+                    Okular::Page *page = newPagesVector[i];
                     page->setObjectRects(generateLinks(pp->links()));
                     rectsGenerated[i] = true;
                     resolveMediaLinkReferences(page);
@@ -881,7 +883,7 @@ bool PDFGenerator::doCloseDocument()
     return true;
 }
 
-void PDFGenerator::loadPages(QVector<Okular::Page *> &pagesVector, int rotation, bool clear)
+void PDFGenerator::loadPages(QList<Okular::Page *> &pagesVector, int rotation, bool clear)
 {
     // TODO XPDF 3.01 check
     const int count = pagesVector.count();
@@ -1049,7 +1051,7 @@ const Okular::DocumentSynopsis *PDFGenerator::generateDocumentSynopsis()
     }
 
     userMutex()->lock();
-    const QVector<Poppler::OutlineItem> outline = pdfdoc->outline();
+    const QList<Poppler::OutlineItem> outline = pdfdoc->outline();
     userMutex()->unlock();
 
     if (outline.isEmpty()) {
@@ -1529,10 +1531,10 @@ Okular::Document::PrintError PDFGenerator::print(QPrinter &printer)
     // Windows can only print by rasterization, because that is
     // currently the only way Okular implements printing without using UNIX-specific
     // tools like 'lpr'.
-    forceRasterize = true;
+    forceRasterize = true; /* cppcheck-suppress redundantAssignment */
 #endif
 
-    if (forceRasterize) {
+    if (forceRasterize) { /* cppcheck-suppress knownConditionTrueFalse */
         pdfdoc->setRenderHint(Poppler::Document::HideAnnotations, !printAnnots);
         pdfdoc->setRenderHint(Poppler::Document::OverprintPreview, overprintPreviewEnabled);
 
@@ -1648,8 +1650,7 @@ Okular::Document::PrintError PDFGenerator::print(QPrinter &printer)
     psConverter->setTitle(pstitle);
 
 #if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(23, 9, 0)
-    const auto isPdfOutput = printer.outputFormat() == QPrinter::PdfFormat;
-    psConverter->setForceOverprintPreview(!isPdfOutput && overprintPreviewEnabled);
+    psConverter->setForceOverprintPreview(overprintPreviewEnabled);
 #endif
 
     if (!printAnnots) {
@@ -1714,7 +1715,7 @@ QVariant PDFGenerator::metaData(const QString &key, const QVariant &option) cons
         return pdfdoc->formType() == Poppler::Document::XfaForm;
     } else if (key == QLatin1String("FormCalculateOrder")) {
         QMutexLocker ml(userMutex());
-        return QVariant::fromValue<QVector<int>>(pdfdoc->formCalculateOrder());
+        return QVariant::fromValue<QList<int>>(pdfdoc->formCalculateOrder());
     } else if (key == QLatin1String("GeneratorExtraDescription")) {
         if (Poppler::Version::string() == QStringLiteral(POPPLER_VERSION)) {
             return i18n("Using Poppler %1", Poppler::Version::string());
@@ -1898,7 +1899,7 @@ Okular::TextPage *PDFGenerator::abstractTextPage(const std::vector<std::unique_p
     return ktp;
 }
 
-void PDFGenerator::addSynopsisChildren(const QVector<Poppler::OutlineItem> &outlineItems, QDomNode *parentDestination)
+void PDFGenerator::addSynopsisChildren(const QList<Poppler::OutlineItem> &outlineItems, QDomNode *parentDestination)
 {
     for (const Poppler::OutlineItem &outlineItem : outlineItems) {
         QDomElement item = docSyn.createElement(outlineItem.name());
@@ -2168,20 +2169,45 @@ bool PDFGenerator::canSign() const
 #endif
 }
 
-bool PDFGenerator::sign(const Okular::NewSignatureData &oData, const QString &rFilename)
+#if POPPLER_VERSION_MACRO > QT_VERSION_CHECK(25, 06, 0)
+static Okular::SigningResult fromPoppler(Poppler::PDFConverter::SigningResult result)
+{
+    switch (result) {
+    case Poppler::PDFConverter::GenericSigningError:
+        return Okular::GenericSigningError;
+    case Poppler::PDFConverter::FieldAlreadySigned:
+        return Okular::FieldAlreadySigned;
+    case Poppler::PDFConverter::BadPassphrase:
+        return Okular::BadPassphrase;
+    case Poppler::PDFConverter::KeyMissing:
+        return Okular::KeyMissing;
+    case Poppler::PDFConverter::InternalError:
+        return Okular::InternalSigningError;
+    case Poppler::PDFConverter::UserCancelled:
+        return Okular::UserCancelled;
+    case Poppler::PDFConverter::WriteFailed:
+        return Okular::SignatureWriteFailed;
+    case Poppler::PDFConverter::SigningSuccess:
+        return Okular::SigningSuccess;
+    }
+    return Okular::GenericSigningError;
+}
+#endif
+
+std::pair<Okular::SigningResult, QString> PDFGenerator::sign(const Okular::NewSignatureData &oData, const QString &rFilename)
 {
     // We need a temporary file to pass a prepared image to poppler
     QTemporaryFile timg(QFileInfo(rFilename).absolutePath() + QLatin1String("/okular_XXXXXX.png"));
     timg.setAutoRemove(true);
     if (!timg.open()) {
-        return false;
+        return {Okular::SignatureWriteFailed, i18n("Failed writing temporary file")};
     }
 
     // save to tmp file - poppler doesn't like overwriting in-place
     QTemporaryFile tf(QFileInfo(rFilename).absolutePath() + QLatin1String("/okular_XXXXXX.pdf"));
     tf.setAutoRemove(false);
     if (!tf.open()) {
-        return false;
+        return {Okular::SignatureWriteFailed, i18n("Failed writing temporary file")};
     }
     std::unique_ptr<Poppler::PDFConverter> converter(pdfdoc->pdfConverter());
     converter->setOutputFileName(tf.fileName());
@@ -2212,18 +2238,23 @@ bool PDFGenerator::sign(const Okular::NewSignatureData &oData, const QString &rF
             }
         }
     }
-    if (!converter->sign(pData)) {
+    bool result = converter->sign(pData);
+    if (!result) {
         tf.remove();
-        return false;
+#if POPPLER_VERSION_MACRO > QT_VERSION_CHECK(25, 06, 0)
+        return {fromPoppler(converter->lastSigningResult()), converter->lastSigningErrorDetails().data.toString()};
+#else
+        return {Okular::GenericSigningError, QString {}};
+#endif
     }
 
     // now copy over old file
     QFile::remove(rFilename);
     if (!tf.rename(rFilename)) {
-        return false;
+        return {Okular::SignatureWriteFailed, i18n("Failed renaming temporary file")};
     }
 
-    return true;
+    return {Okular::SigningSuccess, {}};
 }
 
 Okular::CertificateStore *PDFGenerator::certificateStore() const
