@@ -474,8 +474,8 @@ static QByteArray readFileOrDirectoryParts(const KArchiveEntry *entry, QString *
         const KArchiveDirectory *relDir = static_cast<const KArchiveDirectory *>(entry);
         QStringList entries = relDir->entries();
         std::sort(entries.begin(), entries.end());
-        for (const QString &entry : std::as_const(entries)) {
-            const KArchiveEntry *relSubEntry = relDir->entry(entry);
+        for (const QString &entryElem : std::as_const(entries)) {
+            const KArchiveEntry *relSubEntry = relDir->entry(entryElem);
             if (!relSubEntry->isFile()) {
                 continue;
             }
@@ -953,7 +953,7 @@ void XpsPage::processPath(QPainter *painter, const XpsRenderNode &node)
     att = node.attributes.value(QStringLiteral("StrokeDashArray")).toString();
     if (!att.isEmpty()) {
         const QStringList pieces = att.split(QLatin1Char(' '), Qt::SkipEmptyParts);
-        QVector<qreal> dashPattern(pieces.count());
+        QList<qreal> dashPattern(pieces.count());
         bool ok = false;
         for (int i = 0; i < pieces.count(); ++i) {
             qreal value = pieces.at(i).toInt(&ok);
@@ -1697,8 +1697,8 @@ XpsDocument::XpsDocument(XpsFile *file, const QString &fileName)
             if (docXml.name() == QStringLiteral("PageContent")) {
                 QString pagePath = docXml.attributes().value(QStringLiteral("Source")).toString();
                 qCWarning(OkularXpsDebug) << "Page Path: " << pagePath;
-                auto page = std::make_unique<XpsPage>(file, absolutePath(documentFilePath, pagePath));
-                m_pages.push_back(std::move(page));
+                auto xpsPage = std::make_unique<XpsPage>(file, absolutePath(documentFilePath, pagePath));
+                m_pages.push_back(std::move(xpsPage));
             } else if (docXml.name() == QStringLiteral("PageContent.LinkTargets")) {
                 // do nothing - wait for the real LinkTarget elements
             } else if (docXml.name() == QStringLiteral("LinkTarget")) {
@@ -1968,7 +1968,7 @@ XpsGenerator::~XpsGenerator()
 {
 }
 
-bool XpsGenerator::loadDocument(const QString &fileName, QVector<Okular::Page *> &pagesVector)
+bool XpsGenerator::loadDocument(const QString &fileName, QList<Okular::Page *> &pagesVector)
 {
     m_xpsFile = std::make_unique<XpsFile>();
 
@@ -2062,11 +2062,11 @@ bool XpsGenerator::exportTo(const QString &fileName, const Okular::ExportFormat
 
         QTextStream ts(&f);
         for (int i = 0; i < m_xpsFile->numPages(); ++i) {
-            Okular::TextPage *textPage = m_xpsFile->page(i)->textPage();
-            QString text = textPage->text();
+            Okular::TextPage *tp = m_xpsFile->page(i)->textPage();
+            QString text = tp->text();
             ts << text;
             ts << QLatin1Char('\n');
-            delete textPage;
+            delete tp;
         }
         f.close();
 
