@@ -41,7 +41,7 @@ class XpsRenderNode
 {
 public:
     QString name;
-    QVector<XpsRenderNode> children;
+    QList<XpsRenderNode> children;
     QXmlStreamAttributes attributes;
     QVariant data;
 
@@ -122,10 +122,10 @@ public:
 
 private:
     // Methods for processing of different xml elements
-    void processStartElement(QPainter *painter, XpsRenderNode &node);
+    void processStartElement(QPainter *painter, const XpsRenderNode &node);
     void processEndElement(QPainter *painter, XpsRenderNode &node);
-    void processGlyph(QPainter *painter, XpsRenderNode &node);
-    void processPath(QPainter *painter, XpsRenderNode &node);
+    void processGlyph(QPainter *painter, const XpsRenderNode &node);
+    void processPath(QPainter *painter, const XpsRenderNode &node);
     void processPathData(XpsRenderNode &node);
     void processFill(XpsRenderNode &node);
     void processStroke(XpsRenderNode &node);
@@ -142,7 +142,6 @@ private:
     QString m_thumbnailFileName;
     bool m_thumbnailMightBeAvailable;
     QImage m_thumbnail;
-    bool m_thumbnailIsLoaded;
 
     QImage *m_pageImage;
     bool m_pageIsRendered;
@@ -260,9 +259,7 @@ private:
     QList<XpsPage *> m_pages;
 
     QString m_thumbnailFileName;
-    bool m_thumbnailMightBeAvailable;
     QImage m_thumbnail;
-    bool m_thumbnailIsLoaded;
 
     QString m_corePropertiesFileName;
 
@@ -282,7 +279,7 @@ public:
     XpsGenerator(QObject *parent, const QVariantList &args);
     ~XpsGenerator() override;
 
-    bool loadDocument(const QString &fileName, QVector<Okular::Page *> &pagesVector) override;
+    bool loadDocument(const QString &fileName, QList<Okular::Page *> &pagesVector) override;
 
     Okular::DocumentInfo generateDocumentInfo(const QSet<Okular::DocumentInfo::Key> &keys) const override;
     const Okular::DocumentSynopsis *generateDocumentSynopsis() override;
