@@ -462,7 +462,7 @@ const QIcon AnnotationActionHandlerPrivate::widthIcon(double width)
 
 const QIcon AnnotationActionHandlerPrivate::stampIcon(const QString &stampIconName)
 {
-    QPixmap stampPix = Okular::AnnotationUtils::loadStamp(stampIconName, 32);
+    QPixmap stampPix = Okular::AnnotationUtils::loadStamp(stampIconName, QSize(32, 32));
     if (stampPix.width() == stampPix.height()) {
         return QIcon(stampPix);
     } else {
@@ -749,17 +749,17 @@ AnnotationActionHandler::AnnotationActionHandler(PageViewAnnotator *parent, KAct
     ac->addAction(QStringLiteral("annotation_settings_advanced"), d->aAdvancedSettings);
 
     ac->setDefaultShortcut(d->aToolBarVisibility, Qt::Key_F6);
-    ac->setDefaultShortcut(aHighlighter, Qt::ALT + Qt::Key_1);
-    ac->setDefaultShortcut(aUnderline, Qt::ALT + Qt::Key_2);
-    ac->setDefaultShortcut(aSquiggle, Qt::ALT + Qt::Key_3);
-    ac->setDefaultShortcut(aStrikeout, Qt::ALT + Qt::Key_4);
-    ac->setDefaultShortcut(aTypewriter, Qt::ALT + Qt::Key_5);
-    ac->setDefaultShortcut(aInlineNote, Qt::ALT + Qt::Key_6);
-    ac->setDefaultShortcut(aPopupNote, Qt::ALT + Qt::Key_7);
-    ac->setDefaultShortcut(aFreehandLine, Qt::ALT + Qt::Key_8);
-    ac->setDefaultShortcut(aArrow, Qt::ALT + Qt::Key_9);
-    ac->setDefaultShortcut(aRectangle, Qt::ALT + Qt::Key_0);
-    ac->setDefaultShortcut(d->aAddToQuickTools, QKeySequence((Qt::CTRL | Qt::SHIFT) + Qt::Key_B));
+    ac->setDefaultShortcut(aHighlighter, Qt::ALT | Qt::Key_1);
+    ac->setDefaultShortcut(aUnderline, Qt::ALT | Qt::Key_2);
+    ac->setDefaultShortcut(aSquiggle, Qt::ALT | Qt::Key_3);
+    ac->setDefaultShortcut(aStrikeout, Qt::ALT | Qt::Key_4);
+    ac->setDefaultShortcut(aTypewriter, Qt::ALT | Qt::Key_5);
+    ac->setDefaultShortcut(aInlineNote, Qt::ALT | Qt::Key_6);
+    ac->setDefaultShortcut(aPopupNote, Qt::ALT | Qt::Key_7);
+    ac->setDefaultShortcut(aFreehandLine, Qt::ALT | Qt::Key_8);
+    ac->setDefaultShortcut(aArrow, Qt::ALT | Qt::Key_9);
+    ac->setDefaultShortcut(aRectangle, Qt::ALT | Qt::Key_0);
+    ac->setDefaultShortcut(d->aAddToQuickTools, QKeySequence((Qt::CTRL | Qt::SHIFT) | Qt::Key_B));
     d->updateConfigActions();
 
     connect(Okular::Settings::self(), &Okular::Settings::primaryAnnotationToolBarChanged, this, &AnnotationActionHandler::setupAnnotationToolBarVisibilityAction);
@@ -774,9 +774,9 @@ AnnotationActionHandler::~AnnotationActionHandler()
 void AnnotationActionHandler::setupAnnotationToolBarVisibilityAction()
 {
     // find the main window associated to the toggle toolbar action
-    QList<QWidget *> widgets = d->aToolBarVisibility->associatedWidgets();
-    auto itMainWindow = std::find_if(widgets.begin(), widgets.end(), [](const QWidget *widget) { return qobject_cast<const KParts::MainWindow *>(widget) != nullptr; });
-    Q_ASSERT(itMainWindow != widgets.end());
+    QList<QObject *> objects = d->aToolBarVisibility->associatedObjects();
+    auto itMainWindow = std::find_if(objects.begin(), objects.end(), [](const QObject *object) { return qobject_cast<const KParts::MainWindow *>(object) != nullptr; });
+    Q_ASSERT(itMainWindow != objects.end());
     KParts::MainWindow *mw = qobject_cast<KParts::MainWindow *>(*itMainWindow);
 
     // ensure that the annotation toolbars have been created
@@ -795,7 +795,7 @@ void AnnotationActionHandler::setupAnnotationToolBarVisibilityAction()
         primaryAnnotationToolBar = mw->toolBar(QStringLiteral("quickAnnotationToolBar"));
     }
     d->aToolBarVisibility->setChecked(false);
-    d->aToolBarVisibility->disconnect();
+    d->aToolBarVisibility->disconnect(primaryAnnotationToolBar);
     d->aToolBarVisibility->setChecked(primaryAnnotationToolBar->isVisible());
     connect(primaryAnnotationToolBar, &QToolBar::visibilityChanged, d->aToolBarVisibility, &QAction::setChecked, Qt::UniqueConnection);
     connect(d->aToolBarVisibility, &QAction::toggled, primaryAnnotationToolBar, &KToolBar::setVisible, Qt::UniqueConnection);
