@@ -61,7 +61,7 @@ public:
 
 void KTreeViewSearchLine::Private::rowsInserted(const QModelIndex &parentIndex, int start, int end) const
 {
-    QAbstractItemModel *model = qobject_cast<QAbstractItemModel *>(parent->sender());
+    const QAbstractItemModel *model = qobject_cast<QAbstractItemModel *>(parent->sender());
     if (!model) {
         return;
     }
@@ -216,7 +216,7 @@ void KTreeViewSearchLine::setCaseSensitivity(Qt::CaseSensitivity caseSensitivity
     if (d->caseSensitive != caseSensitivity) {
         d->caseSensitive = caseSensitivity;
         updateSearch();
-        emit searchOptionsChanged();
+        Q_EMIT searchOptionsChanged();
     }
 }
 
@@ -225,7 +225,7 @@ void KTreeViewSearchLine::setRegularExpression(bool value)
     if (d->regularExpression != value) {
         d->regularExpression = value;
         updateSearch();
-        emit searchOptionsChanged();
+        Q_EMIT searchOptionsChanged();
     }
 }
 
@@ -345,66 +345,4 @@ void KTreeViewSearchLine::treeViewDeleted(QObject *treeView)
     d->treeViewDeleted(treeView);
 }
 
-////////////////////////////////////////////////////////////////////////////////
-// KTreeViewSearchLineWidget
-////////////////////////////////////////////////////////////////////////////////
-
-class KTreeViewSearchLineWidget::Private
-{
-public:
-    Private()
-        : treeView(nullptr)
-        , searchLine(nullptr)
-    {
-    }
-
-    QTreeView *treeView;
-    KTreeViewSearchLine *searchLine;
-};
-
-KTreeViewSearchLineWidget::KTreeViewSearchLineWidget(QWidget *parent, QTreeView *treeView)
-    : QWidget(parent)
-    , d(new Private)
-{
-    d->treeView = treeView;
-
-    QTimer::singleShot(0, this, &KTreeViewSearchLineWidget::createWidgets);
-}
-
-KTreeViewSearchLineWidget::~KTreeViewSearchLineWidget()
-{
-    delete d;
-}
-
-KTreeViewSearchLine *KTreeViewSearchLineWidget::createSearchLine(QTreeView *treeView) const
-{
-    return new KTreeViewSearchLine(const_cast<KTreeViewSearchLineWidget *>(this), treeView);
-}
-
-void KTreeViewSearchLineWidget::createWidgets()
-{
-    QLabel *label = new QLabel(i18n("S&earch:"), this);
-    label->setObjectName(QStringLiteral("kde toolbar widget"));
-
-    searchLine()->show();
-
-    label->setBuddy(d->searchLine);
-    label->show();
-
-    QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setSpacing(5);
-    layout->setContentsMargins(0, 0, 0, 0);
-    layout->addWidget(label);
-    layout->addWidget(d->searchLine);
-}
-
-KTreeViewSearchLine *KTreeViewSearchLineWidget::searchLine() const
-{
-    if (!d->searchLine) {
-        d->searchLine = createSearchLine(d->treeView);
-    }
-
-    return d->searchLine;
-}
-
 #include "moc_ktreeviewsearchline.cpp"
