@@ -1,14 +1,11 @@
-/***************************************************************************
- *   Copyright (C) 2004 by Duncan Mac-Vicar Prett <duncan@kde.org>         *
- *   Copyright (C) 2004-2005 by Olivier Goffart <ogoffart@kde.org>         *
- *   Copyright (C) 2011 by Niels Ole Salscheider                           *
- *                         <niels_ole@salscheider-online.de>               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004 Duncan Mac-Vicar Prett <duncan@kde.org>
+    SPDX-FileCopyrightText: 2004-2005 Olivier Goffart <ogoffart@kde.org>
+    SPDX-FileCopyrightText: 2011 Niels Ole Salscheider
+    <niels_ole@salscheider-online.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef LATEXRENDERER_H
 #define LATEXRENDERER_H
