@@ -13,7 +13,9 @@
 #include <KActionCollection>
 
 #include "annotationtools.h"
+#include "core/annotations.h"
 #include "pageviewutils.h"
+#include "signaturepartutils.h"
 
 class QKeyEvent;
 class QMouseEvent;
@@ -69,6 +71,8 @@ public:
     void setSignatureMode(bool enabled);
     bool signatureMode() const;
 
+    void startSigning(SignaturePartUtils::SigningInformation *info);
+
     // returns the preferred cursor for the current tool. call this only
     // if active() == true
     QCursor cursor() const;
